about summary refs log tree commit diff
path: root/pkgs/tools
diff options
context:
space:
mode:
authorWilliam A. Kennington III <william@wkennington.com>2014-01-10 17:21:45 -0600
committerWilliam A. Kennington III <william@wkennington.com>2014-01-10 18:50:42 -0600
commit268ffe1144eb0207fa22a230e1393bfee41eb6b4 (patch)
tree57bd14f5e238b7a262cc50fbc3ea1067afe8681f /pkgs/tools
parentc916c9bc2a9a9beb1192a6a36d94f49a97f84df3 (diff)
downloadnixlib-268ffe1144eb0207fa22a230e1393bfee41eb6b4.tar
nixlib-268ffe1144eb0207fa22a230e1393bfee41eb6b4.tar.gz
nixlib-268ffe1144eb0207fa22a230e1393bfee41eb6b4.tar.bz2
nixlib-268ffe1144eb0207fa22a230e1393bfee41eb6b4.tar.lz
nixlib-268ffe1144eb0207fa22a230e1393bfee41eb6b4.tar.xz
nixlib-268ffe1144eb0207fa22a230e1393bfee41eb6b4.tar.zst
nixlib-268ffe1144eb0207fa22a230e1393bfee41eb6b4.zip
tahoe-lafs: Upgrade from 1.9.2 -> 1.10.0
Remove patches which do not apply to the newer version.
Diffstat (limited to 'pkgs/tools')
-rw-r--r--pkgs/tools/networking/p2p/tahoe-lafs/default.nix35
1 files changed, 7 insertions, 28 deletions
diff --git a/pkgs/tools/networking/p2p/tahoe-lafs/default.nix b/pkgs/tools/networking/p2p/tahoe-lafs/default.nix
index 38adea8af8f9..8796dbd076e7 100644
--- a/pkgs/tools/networking/p2p/tahoe-lafs/default.nix
+++ b/pkgs/tools/networking/p2p/tahoe-lafs/default.nix
@@ -1,5 +1,5 @@
 { fetchurl, lib, unzip, buildPythonPackage, twisted, foolscap, nevow
-, simplejson, zfec, pycryptopp, pysqlite, darcsver, setuptoolsTrial
+, simplejson, zfec, pycryptopp, sqlite3, darcsver, setuptoolsTrial
 , setuptoolsDarcs, numpy, nettools, pycrypto, pyasn1, mock }:
 
 # FAILURES: The "running build_ext" phase fails to compile Twisted
@@ -8,34 +8,18 @@
 # some loss of functionality because of it.
 
 let
-  name = "tahoe-lafs-1.9.2";
+  name = "tahoe-lafs-1.10.0";
 in
 buildPythonPackage {
   inherit name;
   namePrefix = "";
 
   src = fetchurl {
-    url = "http://tahoe-lafs.org/source/tahoe-lafs/snapshots/allmydata-tahoe-1.9.2.tar.bz2";
-    sha256 = "0111gmavyrnglx10kj8z7wm7y97fyg9isv71c0gx9kq4c03knxq4";
+    url = "http://tahoe-lafs.org/source/tahoe-lafs/releases/allmydata-tahoe-1.10.0.tar.bz2";
+    sha256 = "1qng7j1vykk8zl5da9yklkljvgxfnjky58gcay6dypz91xq1cmcw";
   };
 
-  # The patch doesn't apply cleanly to the current version.
-  patches = [ /* ./test-timeout.patch */ ];
-
   configurePhase = ''
-    echo "forcing the use of \`setuptools' 0.6c9 rather than an unreleased version"
-    for i in *setup.py
-    do
-      sed -i "$i" -es'/0.6c12dev/0.6c9/g'
-    done
-
-    # `find_exe()' returns a list like ['.../bin/python'
-    # '.../bin/twistd'], which doesn't work when `twistd' is not a
-    # Python script (e.g., when it's a script produced by
-    # `wrapProgram').
-    sed -i "src/allmydata/scripts/startstop_node.py" \
-        -es"|cmd = find_exe.find_exe('twistd')|cmd = ['${twisted}/bin/twistd']|g"
-
     sed -i "src/allmydata/util/iputil.py" \
         -es"|_linux_path = '/sbin/ifconfig'|_linux_path = '${nettools}/bin/ifconfig'|g"
 
@@ -50,9 +34,9 @@ buildPythonPackage {
   buildInputs = [ unzip ]
     ++ [ numpy ]; # Some tests want this + http://tahoe-lafs.org/source/tahoe-lafs/deps/tahoe-dep-sdists/mock-0.6.0.tar.bz2
 
   # The `backup' command requires `pysqlite'.
   propagatedBuildInputs =
-    [ twisted foolscap nevow simplejson zfec pycryptopp pysqlite
+    [ twisted foolscap nevow simplejson zfec pycryptopp sqlite3
       darcsver setuptoolsTrial setuptoolsDarcs pycrypto pyasn1 mock
     ];
 
@@ -61,11 +45,6 @@ buildPythonPackage {
 
   postInstall = ''
     # Install the documentation.
-
-    # FIXME: Inkscape segfaults when run from here.  Setting $HOME to
-    # something writable doesn't help; providing $FONTCONFIG_FILE doesn't
-    # help either.  So we just don't run `make' under `docs/'.
-
     mkdir -p "$out/share/doc/${name}"
     cp -rv "docs/"* "$out/share/doc/${name}"
     find "$out/share/doc/${name}" -name Makefile -exec rm -v {} \;
@@ -88,7 +67,7 @@ buildPythonPackage {
 
     homepage = http://allmydata.org/;
 
-    license = [ "GPLv2+" /* or */ "TGPPLv1+" ];
+    license = [ lib.licenses.gpl2Plus /* or */ "TGPPLv1+" ];
 
     maintainers = [ lib.maintainers.simons  ];
     platforms = lib.platforms.gnu;  # arbitrary choice
@@ -50,9 +34,9 @@ buildPythonPackage {
     ++ [ numpy ]; # Some tests want this + http://tahoe-lafs.org/source/tahoe-lafs/deps/tahoe-dep-sdists/mock-0.6.0.tar.bz2
 
-  # The `backup' command requires `pysqlite'.
+  # The `backup' command requires `sqlite3'.
   propagatedBuildInputs =